.. _plugin_matrix:


Plugins
=======

This is a list of the currently built in plugins and what URLs and features
they support. Streamlink's primary focus is live streams, so VOD support
is limited.


======================= ==================== ===== ===== ===========================
Name                    URL(s)               Live  VOD   Notes
======================= ==================== ===== ===== ===========================
abematv                 abema.tv             Yes   Yes   Streams are geo-restricted to Japan.
abweb                   abweb.com            Yes   No    Requires a login and a subscription.
adultswim               adultswim.com        Yes   Yes   Streams may be geo-restricted, some VOD streams are protected by DRM.
afreeca                 play.afreecatv.com   Yes   No
albavision              - tvc.com.ec         Yes   No    Some streams are geo-restricted.
                        - rts.com.ec
                        - elnueve.com.ar
                        - atv.pe
aljazeeraen             aljazeera.com        Yes   Yes   English version of the site.
animelab                animelab.com         --    Yes   Requires a login. Streams may be geo-restricted to Australia and New Zealand.
app17                   17app.co             Yes   --
ard_live                daserste.de          Yes   Yes   Streams may be geo-restricted to Germany.
ard_mediathek           - ardmediathek.de    Yes   Yes   Streams may be geo-restricted to Germany.
                        - mediathek... [5]_
artetv                  arte.tv              Yes   Yes
atresplayer             atresplayer.com      Yes   No    Streams are geo-restricted to Spain.
bbciplayer              bbc.co.uk/iplayer    Yes   Yes   Streams may be geo-restricted to the United Kingdom.
beattv                  be-at.tv             Yes   Yes   Playlist not implemented yet.
bfmtv                   bfmtv.com            Yes   Yes
                        01net.com
bigo                    - live.bigo.tv       Yes   --
                        - bigoweb.co
bilibili                live.bilibili.com    Yes   ?
bloomberg               bloomberg.com        Yes   Yes
brightcove              players.brig... [6]_ Yes   Yes
btsports                sport.bt.com         Yes   Yes   Requires subscription account
btv                     btv.bg               Yes   No    Requires login, and geo-restricted to Bulgaria.
canalplus               mycanal.fr           No    Yes   Streams may be geo-restricted to France.
cdnbg                   - tv.bnt.bg          Yes   No    Streams may be geo-restricted to Bulgaria.
                        - bgonair.bg
                        - bitelevision.com
                        - bloombergtv.bg
                        - bstv.bg
                        - inlife.bg
                        - kanal3.bg
                        - mmtvmusic.com
                        - mu-vi.tv
                        - nova.bg
ceskatelevize           ceskatelevize.cz     Yes   Yes   Streams may be geo-restricted to Czechia.
cinergroup              - showtv.com.tr      Yes   No
                        - haberturk.com
                        - showmax.com.tr
                        - showturk.com.tr
                        - bloomberght.com
clubbingtv              clubbingtv.com       Yes   Yes   Requires a login.
cnews                   cnews.fr             Yes   Yes
crunchyroll             crunchyroll.com      --    Yes
cubetv                  cube.tv              Yes   --
cybergame               cybergame.tv         Yes   Yes
dailymotion             dailymotion.com      Yes   Yes
delfi                   - delfi.lt           --    Yes
                        - delfi.ee
                        - delfi.lv
deutschewelle           dw.com               Yes   Yes
dingittv                dingit.tv            Yes   Yes
dlive                   dlive.tv             Yes   Yes
dogan                   - teve2.com.tr       Yes   Yes   VOD is supported for teve2 and kanald
                        - kanald.com.tr
                        - dreamtv.com.tr
                        - cnnturk.com
                        - dreamturk.com.tr
dogus                   - ntvspor.net        Yes   No
                        - kralmuzik.com.tr
                        - ntv.com.tr
                        - eurostartv.com.tr
dommune                 dommune.com          Yes   --
douyutv                 - douyu.com          Yes   Yes
                        - v.douyu.com
drdk                    dr.dk                Yes   Yes   Streams may be geo-restricted to Denmark.
earthcam                earthcam.com         Yes   Yes   Only works for the cams hosted on EarthCam.
egame                   egame.qq.com         Yes   No
ellobo                  ellobo106.com        Yes   -
eltrecetv               eltrecetv.com.ar     Yes   Yes   Streams may be geo-restricted to Argentina.
euronews                euronews.com         Yes   No
europaplus              europaplus.ru        Yes   --
facebook                facebook.com         Yes   Yes
filmon                  filmon.com           Yes   Yes   Only SD quality streams.
foxtr                   fox.com.tr           Yes   No
funimationnow           - funimation.com     --    Yes   :ref:`Requires session cookies <cli-funimationnow>`
                        - funimationnow.uk
galatasaraytv           galatasaray.com      Yes   No
gardenersworld          gardenersworld.com   --    Yes
garena                  garena.live          Yes   --
goltelevision           goltelevision.com    Yes   No    Streams may be geo-restricted to Spain.
goodgame                goodgame.ru          Yes   No    Only HLS streams are available.
googledrive             - docs.google.com    --    Yes
                        - drive.google.com
gulli                   replay.gulli.fr      Yes   Yes   Streams may be geo-restricted to France.
hitbox                  - hitbox.tv          Yes   Yes
                        - smashcast.tv
huajiao                 huajiao.com          Yes   No
huomao                  huomao.com           Yes   No
huya                    huya.com             Yes   No    Temporarily only HLS streams available.
idf1                    idf1.fr              Yes   Yes
ine                     ine.com              ---   Yes
itvplayer               itv.com/itvplayer    Yes   Yes   Streams may be geo-restricted to Great Britain.
invintus                player.invintus.com  Yes   Yes
kingkong                kingkong.com.tw      Yes   --
kugou                   fanxing.kugou.com    Yes   --
latina                  latina.pe            Yes   No    Streams may be geo-restricted to Peru.
linelive                live.line.me         Yes   Yes
live_russia_tv          live.russia.tv       Yes   --
liveedu                 - liveedu.tv         Yes   --    Some streams require a login.
                        - livecoding.tv
liveme                  liveme.com           Yes   --
livestream              new.livestream.com   Yes   --
lrt                     lrt.lt               Yes   No
ltv_lsm_lv              ltv.lsm.lv           Yes   No    Streams may be geo-restricted to Latvia.
mediaklikk              mediaklikk.hu        Yes   No    Streams may be geo-restricted to Hungary.
metube                  metube.id            Yes   Yes
mitele                  mitele.es            Yes   No    Streams may be geo-restricted to Spain.
mixer                   mixer.com            Yes   Yes
mjunoon                 mjunoon.tv           Yes   Yes
nbc                     nbc.com              No    Yes   Streams are geo-restricted to USA. Authentication is not supported.
nbcnews                 nbcnews.com          Yes   No
nbcsports               nbcsports.com        No    Yes   Streams maybe be geo-restricted to USA. Authentication is not supported.
nhkworld                nhk.or.jp/nhkworld   Yes   No
nicolive                live.nicovideo.jp    Yes   Yes   Timeshift is supported. Some content may require login.
nos                     nos.nl               Yes   Yes   Streams may be geo-restricted to Netherlands.
nownews                 news.now.com         Yes   No
nrk                     - tv.nrk.no          Yes   Yes   Streams may be geo-restricted to Norway.
                        - radio.nrk.no
ntv                     ntv.ru               Yes   No
okru                    ok.ru                Yes   Yes
olympicchannel          olympicchannel.com   Yes   Yes   Only non-premium content is available.
oneplusone              1plus1.video         Yes   No
onetv                   - 1tv.ru             Yes   Yes   Streams may be geo-restricted to Russia. VOD only for 1tv.ru
                        - ctc.ru
                        - chetv.ru
                        - ctclove.ru
                        - domashny.ru
openrectv               openrec.tv           Yes   Yes
orf_tvthek              tvthek.orf.at        Yes   Yes
pandatv                 panda.tv             Yes   ?
periscope               periscope.tv         Yes   Yes   Replay/VOD is supported.
picarto                 picarto.tv           Yes   Yes
piczel                  piczel.tv            Yes   No
pixiv                   sketch.pixiv.net     Yes   --
playtv                  - playtv.fr          Yes   --    Streams may be geo-restricted to France.
                        - play.tv
pluzz                   - france.tv          Yes   Yes   Streams may be geo-restricted to France, Andorra and Monaco.
                        - ludo.fr
                        - zouzous.fr
                        - francetvinfo.fr
powerapp                powerapp.com.tr      Yes   No
qq                      live.qq.com          Yes   No
radiko                  radiko.jp            Yes   Yes   Streams are geo-restricted to Japan.
radionet                - radio.net          Yes   --
                        - radio.at
                        - radio.de
                        - radio.dk
                        - radio.es
                        - radio.fr
                        - radio.it
                        - radio.pl
                        - radio.pt
                        - radio.se
raiplay                 raiplay.it           Yes   No    Most streams are geo-restricted to Italy.
reshet                  reshet.tv            Yes   Yes   Streams may be geo-restricted to Israel.
reuters                 reuters.tv           Yes   Yes
rotana                  rotana.net           Yes   --    Streams are geo-restricted to Saudi Arabia.
rtbf                    - rtbf.be/auvio      Yes   Yes   Streams may be geo-restricted to Belgium or Europe.
                        - rtbfradioplayer.be
rtlxl                   rtlxl.nl             No    Yes   Streams may be geo-restricted to The Netherlands. Livestreams not supported.
rtpplay                 rtp.pt/play          Yes   Yes   Streams may be geo-restricted to Portugal.
rtve                    rtve.es              Yes   No    Streams may be geo-restricted to Spain.
rtvs                    rtvs.sk              Yes   No    Streams may be geo-restricted to Slovakia.
ruv                     ruv.is               Yes   Yes   Streams may be geo-restricted to Iceland.
sbscokr                 play.sbs.co.kr       Yes   No    Streams may be geo-restricted to South Korea.
schoolism               schoolism.com        --    Yes   Requires a login and a subscription.
senategov               senate.gov           --    Yes   Supports hearing streams.
showroom                showroom-live.com    Yes   No
skai                    skai.gr              Yes   No    Only embedded youtube live streams are supported
sportal                 sportal.bg           Yes   No
sportschau              sportschau.de        Yes   No
srgssr                  - srf.ch             Yes   No    Streams are geo-restricted to Switzerland.
                        - rts.ch
                        - rsi.ch
                        - rtr.ch
ssh101                  ssh101.com           Yes   No
stadium                 watchstadium.com     Yes   No
startv                  startv.com.tr        Yes   No
steam                   steamcommunity.com   Yes   No    Some streams will require a Steam account.
streamable              streamable.com       -     Yes
streamingvideoprovider  streamingvid... [2]_ Yes   --    RTMP streams requires rtmpdump with
                                                         K-S-V patches.
streamme                stream.me            Yes   --
streann                 ott.streann.com      Yes   Yes
stv                     player.stv.tv        Yes   No    Streams are geo-restricted to Great Britain.
svtplay                 - svtplay.se         Yes   Yes   Streams may be geo-restricted to Sweden.
                        - svtflow.se
                        - oppetarkiv.se
swisstxt                - srf.ch             Yes   No    Streams are geo-restricted to Switzerland.
                        - rsi.ch
tamago                  player.tamago.live   Yes   --
teamliquid              - teamliquid.net     Yes   --
                        - tl.net
teleclubzoom            teleclubzoom.ch      Yes   No    Streams are geo-restricted to Switzerland.
telefe                  telefe.com           No    Yes   Streams are geo-restricted to Argentina.
tf1                     - tf1.fr             Yes   No    Streams may be geo-restricted to France.
                        - lci.fr
tga                     - star.plu.cn        Yes   No
                        - star.tga.plu.cn
                        - star.longzhu.com
theplatform             player.thepl... [7]_ No    Yes
tigerdile               tigerdile.com        Yes   --
tlctr                   tlctv.com.tr         Yes   No
trt                     trt.net.tr           Yes   No    Some streams may be geo-restricted to Turkey.
trtspor                 trtspor.com          Yes   No    Some streams are geo-restricted to Turkey.
turkuvaz                - atv.com.tr         Yes   No
                        - a2tv.com.tr
                        - ahaber.com.tr
                        - anews.com.tr
                        - aspor.com.tr
                        - atvavrupa.tv
                        - minikacocuk.com.tr
                        - minikago.com.tr
                        - sabah.com.tr
tv3cat                  tv3.cat              Yes   Yes   Streams may be geo-restricted to Spain.
tv4play                 - tv4play.se         Yes   Yes   Streams may be geo-restricted to Sweden.
                                                         Only non-premium streams currently supported.
                        - fotbollskanalen.se
tv5monde                - tv5monde.com       Yes   Yes   Streams may be geo-restricted to France, Belgium and Switzerland.
                        - tv5mondeplus.com
                        - tv5mondepl... [8]_
tv8                     tv8.com.tr           Yes   No
tv360                   tv360.com.tr         Yes   No
tvibo                   player.tvibo.com     Yes   --
tvnbg                   - tvn.bg             Yes   -
                        - live.tvn.bg
tvp                     tvpstream.vod.tvp.pl Yes   No    Streams may be geo-restricted to Poland.
tvplayer                tvplayer.com         Yes   No    Streams may be geo-restricted to Great Britain. Premium streams are not supported.
tvrby                   tvr.by               Yes   No    Streams may be geo-restricted to Belarus.
tvrplus                 tvrplus.ro           Yes   No    Streams may be geo-restricted to Romania.
tvtoya                  tvtoya.pl            Yes   --
twitcasting             twitcasting.tv       Yes   No
twitch                  twitch.tv            Yes   Yes
ustreamtv               - ustream.tv         Yes   Yes
                        - video.ibm.com
ustvnow                 ustvnow.com          Yes   --    All streams require an account, some streams require a subscription.
vaughnlive              - vaughnlive.tv      Yes   --
                        - breakers.tv
                        - instagib.tv
                        - vapers.tv
viasat                  - juicyplay.dk       Yes   Yes   Streams may be geo-restricted.
                        - skaties.lv
                        - tv3.dk
                        - tv3.ee
                        - tv3.lt
                        - tv6play.no
                        - viafree.dk
                        - viafree.no
                        - viafree.se
vidio                   vidio.com            Yes   Yes
vimeo                   vimeo.com            Yes   Yes   Password-protected videos are not supported.
vinhlongtv              thvli.vn             Yes   No    Streams are geo-restricted to Vietnam
viutv                   viu.tv               Yes   No    Streams are geo-restricted to Hong Kong
vk                      vk.com               Yes   Yes
vlive                   vlive.tv             Yes   No    Embedded Naver VODs are not supported.
vrtbe                   vrt.be/vrtnu         Yes   Yes
vtvgo                   vtvgo.vn             Yes   No
wasd                    wasd.tv              Yes   Yes
webcast_india_gov       webcast.gov.in       Yes   No    You can use #Channel to indicate CH number.
webtv                   web.tv               Yes   --
welt                    welt.de              Yes   Yes   Streams may be geo-restricted to Germany.
willax                  willax.tv            Yes   No
wwenetwork              network.wwe.com      Yes   Yes   Requires an account to access any content.
youtube                 - youtube.com        Yes   Yes   Protected videos are not supported.
                        - youtu.be
yupptv                  yupptv.com           Yes   Yes   Some streams require an account and subscription.
zattoo                  - zattoo.com         Yes   Yes
                        - nettv.net... [9]_
                        - tvonline.ewe.de
                        - iptv.glat... [10]_
                        - mobiltv.q... [11]_
                        - player.waly.tv
                        - tvplus.m-net.de
                        - www.bbv-tv.net
                        - www.meinewelt.cc
                        - www.myvisiontv.ch
                        - www.netplus.tv
                        - www.quantum-tv.com
                        - www.saktv.ch
                        - www.vtxtv.ch
                        - www.1und1.tv
zdf_mediathek           zdf.de               Yes   Yes   Streams may be geo-restricted to Germany.
zeenews                 zeenews.india.com    Yes   No
zengatv                 zengatv.com          Yes   No
zhanqi                  zhanqi.tv            Yes   No
======================= ==================== ===== ===== ===========================


.. [2] streamingvideoprovider.co.uk
.. [5] mediathek.daserste.de
.. [6] players.brightcove.net
.. [7] player.theplatform.com
.. [8] tv5mondeplusafrique.com
.. [9] nettv.netcologne.de
.. [10] iptv.glattvision.ch
.. [11] mobiltv.quickline.com
